from friday import Friday

Friday.listen("what's the weather ?")
print(Friday._cmd, Friday.reply())
